.. _support:

Support
=======

If you have questions or issues about Niquests, you may:


File an Issue
-------------

If you notice some unexpected behaviour in Niquests, or want to see support
for a new feature,
`file an issue on GitHub <https://github.com/jawah/niquests/issues>`_.
